============
Installation
============

At the command line::

    $ easy_install pyactiviti

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv pyactiviti
    $ pip install pyactiviti
